\name{[-methods}
\docType{methods}
\alias{[-methods}
\alias{[,ANY-method}
\title{Extract or Replace Parts of an Object}
\description{Operators act on objects to extract or replace subsets.}
\seealso{\link{Extract} for the S3 generic.}
\keyword{methods}

\eof
\name{FF}
\alias{FF}
\alias{FFpure}
\title{Estimation of Fundamental Frequencies from a Wspec object}
\description{Estimation of Fundamental Frequencies from an object of class \code{\link{Wspec}}.
    Additionally, some heuristics are used to distinguish silence, noise (and breathing for singers) 
    from real tones.}
\usage{
FF(object, peakheight = 0.01, silence = 0.2, minpeak = 9, diapason = 440, 
    notes = NULL, interest.frqs = seq(along = object@freq),
    search.par = c(0.8, 10, 1.3, 1.7))
    
FFpure(object, peakheight = 0.01, diapason = 440, 
    notes = NULL, interest.frqs = seq(along = object@freq),
    search.par = c(0.8, 10, 1.3, 1.7))
}

\arguments{
  \item{object}{An object of class \code{\link{Wspec}}.}
  \item{peakheight}{The peak's proportion of the maximal peak height to be 
    considered for fundamental frequency detection.
    The default (0.01) means peaks smaller than 0.02 times the maximal peak height are omitted.}
  \item{silence}{The maximum proportion of periodograms to be considered as silence or noise (such as breathing).
    The default (0.2) means that less than 20 out of 100 periodograms represent silence or noise.}
  \item{minpeak}{If more than \code{minpeak} peaks are considered for detection and passed argument \code{peakheight},
    such periodograms are detected to be silence or noise (if \code{silence > 0}).}
  \item{diapason}{Frequency of diapason a, default is 440 (Hertz).}
  \item{notes}{Optional, a vector of integers indicating the notes (in halftones from diapason a)
    that are expected. By applying this restriction, the \dQuote{detection error} might be reduced in some cases.}
  \item{interest.frqs}{Optional, either a vector of integers indicating the 
      indices of (fundamental) frequencies in \code{object} that are expected,
      or one of the character strings \code{"bass"}, \code{"tenor"}, \code{"alto"} or \code{"soprano"}.
      For these voice types, only typical frequency ranges are considered for detection.
        
      By applying this restriction, the \dQuote{detection error} might be reduced in some cases.}
  \item{search.par}{Parameters to look for peaks:
    \enumerate{
        \item The first peak larger than \code{peakheight * 'largest_peak'} is taken.
        \item Its frequency is multiplied by \code{1+search.par[1]}
            Now, any larger peak between the old peak and that value is taken,
            if (a) it exists and if (b) it is above the \code{search.par[2]}-th Fourier-Frequency.
        \item Within the interval of frequencies \code{'current peak' * search.par[3:4]},
            another high peak is looked for. If any high peak exists in that interval, 
            it can be assumed we got the wrong partial and the \sQuote{real} fundamental frequency can be re-estimated 
            from the next two partials.}}
}
\details{\code{FFpure} just estimates the fundamental frequencies for all periodograms contained in the 
    \code{object} (of class \code{\link{Wspec}}.
    
    \code{FF} additionally uses some heuristics to distinguish silence, noise (and breathing for singers) 
    from real tones. It is recommended to use the wrapper function \code{FF} rather than \code{FFpure}.
    If silence detecion can be omitted by specifying \code{silence = 0}.
}
\value{
   Vector of estimated fundamental frequencies (in Hertz) for each periodogram conatined in \code{object}.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\note{These functions are still in development and may be changed in due course.}
\seealso{\code{\link{Wspec}}, \code{\link{periodogram}} (including an example), and \code{\link{noteFromFF}}}
\keyword{ts}

\eof
\name{Mono-Stereo}
\alias{mono}
\alias{stereo}
\title{Converting (extracting, joining) stereo to mono and vice versa}
\description{Functions to extract a channel from a stereo \code{Wave} object,
    and to join channels of two monophonic \code{Wave} objects to a stereophonic one.}
\usage{
mono(object, which = c("left", "right"))
stereo(left, right)
}
\arguments{
    \item{object}{Object of class \code{\link{Wave}}.}
    \item{which}{Character, indicating whether the \dQuote{left} or \dQuote{right} channel should be extracted.}
    \item{left}{Object of class \code{\link{Wave}} containing \code{mono}phonic sound,
        to be used for the left channel.}
    \item{right}{Object of class \code{\link{Wave}} containing \code{mono}phonic sound,
        to be used for the right channel.}    
}
\value{
    An object of class \code{\link{Wave}}.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}}
\examples{
x <- seq(0, 2*pi, length = 44100)
Wobj <- Wave(left = round(32000 * sin(440 * x)))
Wobj
Wobj2 <- stereo(Wobj, Wobj)
Wobj2
mono(Wobj2, "right")
}
\keyword{manip}
\keyword{utilities}


\eof
\name{Wave-class}
\docType{class}
\docType{methods}
\alias{Wave}
\alias{Wave-methods}
\alias{Wave,ANY-method}
\alias{Wave,numeric-method}
\alias{Wave,matrix-method}
\alias{Wave,data.frame-method}
\alias{Wave,list-method}
\alias{Wave-class}
\alias{[,Wave-method}
\alias{coerce,matrix,Wave-method}
\alias{coerce,data.frame,Wave-method}
\alias{coerce,list,Wave-method}
\alias{coerce,numeric,Wave-method}
\alias{coerce,Wave,data.frame-method}
\alias{coerce,Wave,matrix-method}
\alias{coerce,Wave,list-method}
\title{Class Wave and constructors}
\description{Class \dQuote{Wave} and its constructor functions}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("Wave", ...)},
or more conveniently using the function \code{Wave}.
}
\usage{
Wave(left, ...)
\S4method{Wave}{numeric}(left, right = numeric(0), samp.rate = 44100, bit = 16, ...)
}
\arguments{
    \item{left, right, samp.rate, bit}{See Section \dQuote{Slots}.}
    \item{...}{Further arguments to be passed to the default method \code{Wave.default}.}
}
\section{Slots}{
  \describe{
    \item{\code{left}:}{Object of class \code{"numeric"} representing the left channel.}
    \item{\code{right}:}{Object of class \code{"numeric"} representing the right channel,
        \code{NULL} if mono.}
    \item{\code{stereo}:}{Object of class \code{"logical"} indicating whether this
        is a stereo (two channels) or mono representation.}
    \item{\code{samp.rate}:}{Object of class \code{"numeric"} - the sampling rate, e.g. 44100 for CD quality.}
    \item{\code{bit}:}{Object of class \code{"numeric"}, common is 16 for CD quality, or
        8 for a rather rough representation.}
  }
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{writeWave}}, \code{\link{readWave}}}
\examples{
# constructing a Wave object (1 sec.) containing sinus sound with 440Hz:
x <- seq(0, 2*pi, length = 44100)
channel <- round(32000 * sin(440 * x))
Wobj <- Wave(left = channel)
Wobj
}
\keyword{classes}
\keyword{methods}

\eof
\name{WaveIO}
\alias{readWave}
\alias{writeWave}
\title{Reading and writing Wave files}
\description{Reading and writing Wave files.}
\usage{
readWave(filename)
writeWave(object, filename)
}
\arguments{
    \item{filename}{Filename of the file to be read or written.}
    \item{object}{Object of class \code{\link{Wave}} to be written to a Wave file.}
}
\value{
    \code{readWave} returns an object of class \code{\link{Wave}}.

    \code{writeWave} creates a Wave file, but returns nothing.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{writeWave}}, \code{\link{Wave}}}
\examples{
x <- seq(0, 2*pi, length = 44100)
Wobj <- Wave(left = round(32000 * sin(440 * x)))
Wobj

tdir <- tempdir()
tfile <- file.path(tdir, "myWave.wav")
writeWave(Wobj, filename = tfile)
list.files(tdir, pattern = "\\.wav$")
newWobj <- readWave(tfile)
newWobj
file.remove(tfile)
}
\keyword{IO}
\keyword{file}

\eof
\name{Wspec-class}
\docType{class}
\alias{Wspec-class}
\alias{[,Wspec-method}
\alias{Wspec}
\title{Class Wspec}
\description{Class \dQuote{Wspec} (\emph{W}ave \emph{spec}trums).
    Objects of this class represent a bunch of periodograms 
    (see \code{\link{periodogram}}, each generated by \code{\link{spectrum}})
    corresponding to one or several windows of one \code{\link{Wave}} object.
    Redundancy (e.g. same frequencies in each of the periodograms) will be omitted, 
    hence reducing memory consumption.
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("Wspec", ...)},
but regularly they will be created by calls to the function \code{\link{periodogram}}.
}
\section{Slots}{
    The following slots are defined. For details see the constructor function \code{\link{periodogram}}.
  \describe{
    \item{\code{freq}:}{Object of class \code{"numeric"}}
    \item{\code{spec}:}{Object of class \code{"list"}}
    \item{\code{kernel}:}{Object of class \code{"ANY"}}
    \item{\code{df}:}{Object of class \code{"numeric"}}
    \item{\code{taper}:}{Object of class \code{"numeric"}}
    \item{\code{width}:}{Object of class \code{"numeric"}}
    \item{\code{overlap}:}{Object of class \code{"numeric"}}
    \item{\code{normalize}:}{Object of class \code{"logical"}}
    \item{\code{starts}:}{Object of class \code{"numeric"}}
    \item{\code{stereo}:}{Object of class \code{"logical"}}
    \item{\code{samp.rate}:}{Object of class \code{"numeric"}}
    \item{\code{variance}:}{Object of class \code{"numeric"}}
    \item{\code{energy}:}{Object of class \code{"numeric"}}
  }
}
\details{
The subset function \dQuote{\code{[}} extracts the selected 
elements of slots \code{spec}, \code{starts}, \code{variance} and \code{energy}
and returns the other slots unchanged.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\itemize{
    \item the \code{show}, \code{plot} and \code{summary} methods,
    \item for the constructor function and some examples: \code{\link{periodogram}} 
        (and hence also \code{\link{spec.pgram}} and \code{\link{Wave}}).
    }
}
\keyword{classes}

\eof
\name{bind}
\alias{bind}
\title{Concatenating Wave objects}
\description{Concatenating objects of class \code{Wave}.}
\usage{
bind(...)
}
\arguments{
  \item{\dots}{Objects of class \code{\link{Wave}}, each of the same kind (checked by \code{\link{equalWave}}),
   i.e. identical  sampling rate, resolution (bit), and number of channels (stereo/mono).}
}
\value{
    An object of class \code{\link{Wave}}.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}, \code{\link{extractWave}}, \code{\link{stereo}}}
\keyword{manip}
\keyword{utilities}

\eof
\name{channel}
\alias{channel}
\title{Channel conversion for Wave objects}
\description{Convenient wrapper to extract one or more channels from an object of class \code{Wave}
    and return it in form of a data frame.}
\usage{
channel(object, which = c("both", "left", "right"))
}
\arguments{
  \item{object}{Object of class \code{\link{Wave}}.}
  \item{which}{Character indicating which channel(s) should be returned in form of a data frame.}
}
\value{Data frame containing the data of one or two channels from the corresponding \code{Wave} object.}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}, \code{\link{mono}}, \code{\link{extractWave}}}
\keyword{manip}
\keyword{utilities}

\eof
\name{downsample}
\alias{downsample}
\title{Downsampling a Wave object}
\description{Downsampling an object of class \code{Wave}.}
\usage{
downsample(object, samp.rate)
}
\arguments{
    \item{object}{Object of class \code{\link{Wave}}.}
    \item{samp.rate}{Sampling rate the object is to be downsampled to.
        \code{samp.rate} must be in \code{[2000, 192000]}; 
        typical values are 11025, 22050, and 44100 for CD quality.
        If the \code{object}'s sampling rate is already equal or smaller than \code{samp.rate},
        the \code{object} will be returned unchanged.}
}
\value{
    An object of class \code{\link{Wave}}.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}}
\keyword{manip}
\keyword{utilities}


\eof
\name{equalWave}
\alias{equalWave}
\title{Checking Wave objects}
\description{Checks for some kind of equality of objects of class \code{Wave}.}
\usage{
equalWave(object1, object2)
}
\arguments{
  \item{object1, object2}{Object(s) of class \code{\link{Wave}}.}
}
\value{
    Does not return anything. 
    It \code{\link{stop}}s code execution with an error message indicating the problem 
    if the two objects don't have the same properties, i.e.
    identical sampling rate, resolution (bit), and number of channels (stereo/mono).
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}}
\keyword{error}
\keyword{utilities}

\eof
\name{extractWave}
\alias{extractWave}
\title{Extractor for Wave objects}
\description{Extractor function that allows to extract inner parts for \code{Wave} objects (interactively).}
\usage{
extractWave(object, from = 1, to = length(object@left), 
    interact = interactive(), xunit = c("samples", "time"), ...)
}
\arguments{
  \item{object}{Object of class \code{\link{Wave}}.}
  \item{from}{Sample number or time in seconds (see \code{xunit}) at which to \emph{start} extraction.}
  \item{to}{Sample number or time in seconds (see \code{xunit}) at which to \emph{stop} extraction.
    If \code{to < from}, \code{object} will be returned as is.}
  \item{interact}{Logical indicating whether to choose the range to be extracted interactively (if \code{TRUE}). 
    See Section Details.}
  \item{xunit}{Character indicating which units are used to specify the range to be extracted
    (both in arguments \code{from} and \code{to}, and in the plot, if \code{interact = TRUE}).
    If \code{xunit = "time"}, the unit is time in seconds, otherwise the number of samples.}
  \item{\dots}{Parameters to be passed to the underlying plot function (\code{\link{plot-methods}}), 
    if \code{interact = TRUE}.} 
}
\details{
This function allows interactive selection of a range to be extracted from an object of class \code{\link{Wave}}.
The default is to use interactive selection, if the current R session is \code{\link{interactive}}.
In case of interactive selection, \code{\link{plot-methods}} plot the \code{\link{Wave}} object,
and the user may click on the starting and ending points of his selection (given neither \code{from} nor \code{to}
have been specified, see below). 
The cut-points are drawn and the corresponding selection will be returned in form of a \code{\link{Wave}} object.

Setting \code{interact = TRUE} in a non-interactive session does not work.

Setting arguments \code{from} or \code{to} explicitly means that the specified one 
    does not need to be selected interactively, hence only the non-specified one will be selected interactively.
Moreover, setting both \code{from} or \code{to} implies \code{interact = FALSE}.
}
\value{
    An object of class \code{\link{Wave}}.
}
\examples{
x <- seq(0, 2*pi, length = 44100)
Wobj <- Wave(left = round(32000 * sin(440 * x)))
# extracting the middle 0.5 seconds of that 1 sec. sound:
Wobj2 <- extractWave(Wobj, from = 0.25, to = 0.75, xunit = "time")
Wobj2

\dontrun{
# or interactively:
Wobj2 <- extractWave(Wobj)
}
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}, \code{\link{bind}}, \code{\link{channel}}, \code{\link{mono}}}
\keyword{manip}
\keyword{utilities}
\keyword{iplot}

\eof
\name{lilyinput}
\alias{lilyinput}
\title{Providing LilyPond compatible input}
\description{A function \emph{(in development!)} that writes a file to be processed by \emph{LilyPond}
    by extracting the relevant information (e.g. pitch, length, ...) from columns of a data frame.
    The music notation software \emph{LilyPond} can \dQuote{transcribe} such an input file into sheet music.
}
\usage{
lilyinput(X, file = "Rsong.ly", Dur = TRUE, grundton = "c", 
    schlusselart = 1, takt = "4/4", endbar = TRUE, midi = TRUE, 
    tempo = "2 = 60", textheight = 220, linewidth = 150, indent = 0)
}
\arguments{
  \item{X}{A data frame containing 4 named components (columns):
    \itemize{
        \item \code{noten}: Integer - the notes' pitch in halftones from diapason (a),
            i.e. 0 for diapason a, 3 for c', ...
        \item \code{laenge}: Integer - denominator of lengths of the notes, e.g. 8 for a quaver.
        \item \code{punkt}: Logical - whether to punctate a note.
        \item \code{bindung}: Logical - \code{TRUE} indicates to start a slur, or to end it.
            That means that the first, third, ... occurences of \code{TRUE} start slurps,
            while the second, fourth, ... occurences end slurps.
            Note that it is only possible to draw one slur at a time.
    }
  }
  \item{file}{The file to be written for \emph{LilyPond}'s input.}
  \item{Dur}{Logical indicating major key (if \code{TRUE}) or minor key.}
  \item{grundton}{Keynote, necessary to set sharps/flats.}
  \item{schlusselart}{Integer indicating the kind of clef. The following four kinds are supported:
    1 for g-/treble-clef, 2 for f-/bass-clef, 3 for c-/alto-clef, and 4 for c-/tenor-clef.}
  \item{takt}{Character indicating which meter to use, examples are: \code{"3/4"}, \code{"4/4"}.}
  \item{endbar}{Logical indicating whether to set an ending bar at the end of the sheet music.}
  \item{midi}{Logical indicating whether Midi output (by \emph{LilyPond}) is desirable.}
  \item{tempo}{Character specifying the tempo to be used for the Midi file if \code{midi = TRUE}.
    The default, \code{"2 = 60"} indicates: 60 half notes per minute, whereas \code{"4 = 90"}
    indicates 90 quarters per minute.}
  \item{textheight}{Textheight of the sheet music te be written by \emph{LilyPond}.}
  \item{linewidth}{Linewidth of the sheet music te be written by \emph{LilyPond}.}
  \item{indent}{Indentation of the sheet music te be written by \emph{LilyPond}.}
}
\details{
    Details will be given when development has reached a stable stage ...
}
\value{
    Nothing is returned, but a \code{file} is written.
}
\references{
    Nienhuys, H.-W., Nieuwenhuizen, J. et al. (2004):
    \emph{GNU LilyPond - The Music Typesetter}.
    Free Software Foundation, \url{http://www.lilypond.org/}, Version 2.0.3.

    Preusser, A., Ligges, U. und Weihs, C. (2002): 
    \emph{Ein R Exportfilter fr das Notations- und Midi-Programm LilyPond}.   
    Arbeitsbericht 35. Fachbereich Statistik, Universitt Dortmund. (german)
}
\author{Andrea Preusser and Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\note{
    This function is in development! 
    Everything, in particular its user interface (and german names of arguments) is subject to change!
}
\seealso{Functions to be referenced are not yet documented ...}
\examples{
# Not yet available ...
}
\keyword{file}
\keyword{interface}

\eof
\name{melodyplot}
\alias{melodyplot} 
\title{Plotting a melody}
\description{Plot a observed melody and (optional) an expected melody, 
    as well as corresponding energy values (corresponding to the loudness of the sound).}
\usage{
melodyplot(object, observed, expected = NULL, bars = NULL, 
    main = NULL, xlab = NULL, ylab = "note", xlim = NULL, ylim = NULL, 
    observedcol = "red", expectedcol = "grey", gridcol = "grey",
    lwd = 2, las = 1, cex.axis = 0.9, mar = c(5, 4, 4, 4) + 0.1)
}
\arguments{
  \item{object}{An object of class \code{\link{Wspec}}.}
  \item{observed}{Observed notes, probably as a result from \code{\link{noteFromFF}} (or a smoothed version).
    This should correspond to the \code{\link{Wspec}} \code{object}.}
  \item{expected}{Expected notes (optional; in order to compare results).}
  \item{bars}{Number of bars to be plotted (a virtual static segmentation takes place).
    If \code{NULL} (default), time rather than bars are used.}
  \item{main}{Main title of the plot.}
  \item{xlab}{Annotation of x-axis.}
  \item{ylab}{Annotation of y-axis.}
  \item{xlim}{Range of x-axis.}
  \item{ylim}{Range of y-axis.}
  \item{observedcol}{Colour for the oberved melody.}
  \item{expectedcol}{Colour for the expected melody.}
  \item{gridcol}{Colour of the grid.}
  \item{lwd}{Line width, see \code{\link{par}} for details.}
  \item{las}{Orientation of axis labels, see \code{\link{par}} for details.}
  \item{cex.axis}{Size of tick mark labels, see \code{\link{par}} for details.}
  \item{mar}{Margins of the plot, see \code{\link{par}} for details.}
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{noteFromFF}}, \code{\link{FF}}}
\keyword{hplot}

\eof
\name{noteFromFF}
\alias{noteFromFF}
\title{Deriving notes from frequencies}
\description{Deriving notes from given (fundamental) frequencies.}
\usage{
noteFromFF(x, diapason = 440)
}
\arguments{
    \item{x}{Fundamental frequency.}
    \item{diapason}{Frequency of diapason a, default is 440 (Hertz).}
}
\value{
An integer representing the (rounded) difference in halftones from diapason a,
    i.e. indicating the note that corresponds to fundamental frequency \code{x} given the value of \code{diapason}.
    For example: 0 indicates diapason a, 3: c', 12: a', \dots
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{FF}}, and \code{\link{periodogram}} for an example}
\keyword{utilities}


\eof
\name{periodogram}
\alias{periodogram}
\title{Periodogram (Spectral Density) Estimation on Wave objects}
\description{This function estimates one or more periodograms (spectral densities) 
    of the time series contained in an object of class \code{Wave}
    using a window running through the time series (possibly with overlapping).
    It returns an object of class \code{Wspec}.}
\usage{
periodogram(object, width = length(object@left), overlap = 0, 
    starts = NULL, ends = NULL, taper = 0, normalize = TRUE, ...)
}
\arguments{
  \item{object}{An object of class \code{\link{Wave}}.}
  \item{width}{A window of width \sQuote{\code{width}} running through the time series selects the samples 
    from which the periodograms are to be calculated.}
  \item{overlap}{The window can be applied by each overlapping \code{overlap} samples.}
  \item{starts}{Start number (in samples) for a window.
    If not given, this value is derived from argument \code{ends},
    or will be derived \code{width} and \code{overlap}.}
  \item{ends}{End number (in samples) for a window.
    If not given, this value is derived from argument \code{starts},
    or will be derived from \code{width} and \code{overlap}.}
  \item{taper}{proportion of data to taper. See \code{\link{spec.pgram}} for details.}
  \item{normalize}{Logical; if \code{TRUE} (default), two steps will be applied:
    (i) the input signal will be normalized to amplitude \code{max(abs(amplitude)) == 1},
    (ii) the resulting \code{spec} values will be normalized to sum up to one for each periodogram.}
  \item{\dots}{Further arguments to be passed to the underlying function \code{\link{spec.pgram}}.}
}
\value{
An object of class \code{\link{Wspec}} is returned containing the following slots.
    \item{freq}{Vector of frequencies at which the spectral density is estimated. 
        See \code{\link{spectrum}} for details. (1)}
    \item{spec}{List of vectors or matrices of the \code{spec} values returned by \code{\link{spec.pgram}}
        at frequencies corresponding to \code{freq}.
        Each element of the list corresponds to one periodogram estimated from samples of the window
        beginning at \code{start} of the \code{\link{Wave}} object.}
    \item{kernel}{The kernel argument, or the kernel constructed from spans returned by \code{\link{spec.pgram}}. (1)}
    \item{df}{The distribution of the spectral density estimate can be approximated by a chi square distribution with 
        \code{df} degrees of freedom. (1)}
    \item{taper}{The value of the \code{taper} argument. (1)}
    \item{width}{The value of the \code{width} argument. (1)}
    \item{overlap}{The value of the \code{overlap} argument. (1)}
    \item{normalize}{The value of the \code{normalize} argument. (1)}
    \item{starts}{If the argument \code{starts} was given in the call, its value.
        If the argument \code{ends} was given in the call, \sQuote{\code{ends - width}}.
        If neither \code{starts} nor \code{ends} was given, the start points of all periodograms.
        In the latter case the start points are calculated from the arguments \code{width} and \code{overlap}.}
    \item{stereo}{Whether the underlying \code{\link{Wave}} \code{object} was stereo ot not. (1)}
    \item{samp.rate}{Sampling rate of the underlying \code{\link{Wave}} \code{object}. (1)}
    \item{variance}{The variance of samples in each window, corresponding to amplitude / loudness of sound.}
    \item{energy}{The \dQuote{energy} \eqn{E}{E}, also an indicator for the amplitude / loudness of sound:
       \deqn{E(x_I) := 20 * log_{10} \sum_{j\in I}|x_j|,}{%
             E(x_I) := 20 * log_{10} sum_{j in I} |x_j|,}
       where \eqn{I}{I} indicates the interval \eqn{I:=}{I:=} \code{start[i]:end[i]} for all 
       \eqn{i:=1,\dots,}{1:=1,...,} \code{length(starts)}.
    }
Those slots marked with \dQuote{(1)} contain the information once, 
because it is unique for all periodograms of estimated by the function call.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\note{
This function is still in development. 
Support for processing of stereo \code{\link{Wave}} objects has not yet been implemented.
}
\seealso{\itemize{
    \item for the resulting objects' class: \code{\link{Wspec}},
    \item for plotting: \code{\link{plot-Wspec}},  
    \item for the underlying periodogram calculations: \code{\link{spec.pgram}},
    \item for the input data class: \code{\link{Wave}}.
}}
\examples{
# constructing a Wave object (1 sec.) containing sinus sound with 440Hz:
x <- seq(0, 2*pi, length = 44100)
channel <- round(32000 * sin(440 * x))
Wobj <- Wave(left = channel)
Wobj

# Calculate periodograms in windows of 4096 samples each - without
#   any overlap - resulting in an Wspec object that is printed:
Wspecobj <- periodogram(Wobj, width = 4096)
Wspecobj

# Plot the first periodogram from Wspecobj:
plot(Wspecobj)
# Plot the third one and choose a reasonable xlim:
plot(Wspecobj, which = 3, xlim = c(0, 1000))
# Mark frequency that has been generated before:
abline(v = 440, col="red")

FF(Wspecobj)              # all ~ 440 Hertz
noteFromFF(FF(Wspecobj))  # all diapason a
}
\keyword{ts}

\eof
\name{play-methods}
\docType{methods}
\alias{play-methods}
\alias{play}
\alias{play,character-method}
\alias{play,Wave-method}
\title{Playing Waves}
\description{Plays wave files and objects of class Wave.}
\usage{
play(object, player, ...)
}
\arguments{
    \item{object}{Either a filename pointing to a Wave file, 
        or an object of class \code{\link{Wave}}.
        If the latter, it is written to a temporary file by \code{\link{writeWave}},
        played by the chosen player, and deleted afterwards.}
    \item{player}{(Path to) a program capable of playing a wave file by invocation from the command line.
        If under Windows and no player is given, \dQuote{mplay32.exe} will be chosen as the default.}
    \item{\dots}{Further arguments passed to the Wave file \code{player}.
        If no \code{player} and no further arguments are given under Windows, the default is: \code{"/play /close"}.}
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}, \code{\link{writeWave}}}
\keyword{utilities}
\keyword{IO}
\keyword{interface}
\keyword{methods}

\eof
\name{plot-Wave}
\docType{methods}
\alias{plot,Wave,missing-method}
\alias{plot.Wave.channel}
\title{Plotting Wave objects}
\description{Plotting objects of class \code{Wave}.}
\usage{
\S4method{plot}{Wave,missing}(x, info = FALSE, xunit = c("time", "samples"), 
    ylim = NULL, main = NULL, sub = NULL, xlab = NULL, ylab = NULL, 
    simplify = TRUE, nr = 1500, ...)
    
plot.Wave.channel(x, xunit, ylim, xlab, ylab, main, nr, simplify, ...)
}
\arguments{
  \item{x}{Object of class \code{\link{Wave}}.}
  \item{info}{Logical, whether to include (written) information on the \code{\link{Wave}} object within the plot.}
  \item{xunit}{Character indicating which units are used for setting up user coodinates (see \code{\link{par}})
    and x-axis labeling. If \code{xunit = "time"}, the unit is time in seconds, otherwise the number of samples.}
  \item{ylim}{The \code{y} (amplitude) limits of the plot.}
  \item{main, sub}{A main / sub title for the plot.}
  \item{xlab, ylab}{Label for x-/y-axis.}
  \item{simplify}{Logical, whether the plot should be \dQuote{simplified}.
    If \code{TRUE} (default), not all (thousand/millions/billions) of points (samples) of the 
    \code{\link{Wave}} object are drawn, 
    but the \code{nr} (see below) ranges (in form of segments) within \code{nr} windows of the time series.
    
    Plotting with \code{simplify = FALSE} may take several minutes (depending on the number of samples in the \code{Wave})
    and output in any vector format may be really huge.}
  \item{nr}{Number of windows (segments) to be used \emph{approximately}
        (an appropriate number close to \code{nr} is selected)
        to \code{simplify} (see above) the plot.
        Only used if \code{simplify = TRUE} and the number of samples of \code{Wave} object \code{x} is larger.}
  \item{\dots}{Further arguments to be passed to the underlying plot functions.}
}
\details{Function \code{plot.Wave.channel} is a helper function
    to plot a single (left!) channel; in particular it is \emph{not} intended to be called by the user directly.}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}}
\keyword{hplot}
\keyword{aplot}
\keyword{methods}

\eof
\name{plot-Wspec}
\docType{methods}
\alias{plot-Wspec}
\alias{plot,Wspec,missing-method}
\title{Plotting Wspec objects}
\description{Plotting a periodogram contained in an object of class \code{Wspec}.}
\usage{
\S4method{plot}{Wspec,missing}(x, which = 1, type = "h", xlab = "Frequency", 
    ylab = NULL, log = "", ...)
}
\arguments{
  \item{x}{Object of class \code{\link{Wspec}}.}
  \item{which}{Integer indicating which of the periodograms contained in object \code{x} to plot.
    Default is to plot the first one.}
  \item{type}{The default is to plot horizontal lines, rather than points. See \code{\link{plot.default}} for details.}
  \item{xlab, ylab}{Label for x-/y-axis.}
  \item{log}{Character - \code{"x"} if the x axis is to be logarithmic, 
    \code{"y"} if the y axis is to be logarithmic (quite typical for some visualizations of periodograms), 
    and \code{"xy"} or \code{"yx"} if both axes are to be logarithmic.}
  \item{\dots}{Further arguments to be passed to the underlying plot functions. 
    See \code{\link{plot.default}} for details.}
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wspec}},
    and \code{\link{periodogram}} for the constructor function and some examples.}}
\keyword{hplot}
\keyword{methods}

\eof
\name{plot}
\docType{methods}
\alias{plot-methods}
\alias{plot,ANY,ANY-method}
\title{S4 generic for plot}
\description{S4 generic for plot.}
\section{Methods}{
\describe{
\item{x = "ANY", y = "ANY"}{Any object for which a plot is desired.}
}}
\seealso{For the S3 generic: \code{\link[base]{plot.default}}}
\keyword{hplot}
\keyword{aplot}
\keyword{methods}

\eof
\name{show-WaveWspec-methods}
\docType{methods}
\alias{show,Wave-method}
\alias{show,Wspec-method}
\title{Showing objects}
\description{Showing \code{Wave} and \code{Wspec} objects.}
\section{Methods}{
\describe{
\item{object = "Wave"}{The \code{Wave} object is beeing \code{show}ed.
    The number of samples, duration in seconds, Samplingrate (Hertz),
    Stereo / Mono, and the resolution in bits are printed.
    Note that it does not make sense to print the whole channels 
    containing several thousands or millions of samples.}
\item{object = "Wspec"}{The number of periodograms, Fourier frequencies, window width (used amount of data), 
    amount of overlap of neighboring windows, and whether the periodogram(s) has/have been normalized
    will be printed.}
}}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{\code{\link{Wave}}, \code{\link{Wspec}}, \code{\link{plot-methods}}, \code{\link{summary-methods}},
    and \code{\link{periodogram}} for the constructor function and some examples}
\keyword{methods}
\keyword{print}

\eof
\name{smoother}
\alias{smoother}

\title{meta function for smoothers}
\description{Apply a smoother to estimated notes.
Currently, only a running median (using \code{\link[pastecs]{decmedian}} in package \pkg{pastecs}) is available.}
\usage{
smoother(notes, method ="median", order = 4, times = 2)
}

\arguments{
\item{notes}{Series of notes.}
\item{method}{Currently, only a running \code{'median'} 
    (using \code{\link[pastecs]{decmedian}} in package \pkg{pastecs}) is available.}
\item{order}{The window used for the running median corresponds to 2*order + 1.}
\item{times}{The number of times the running median is applied (default: 2).}
}
\value{
The smoothed series of notes.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\keyword{misc}
\keyword{ts}


\eof
\name{summary-methods}
\docType{methods}
\alias{summary-methods}
\alias{summary,ANY-method}
\alias{summary,Wave-method}
\alias{summary,Wspec-method}
\title{Object Summaries}
\description{
summary is a generic function used to produce result summaries of the results of various model fitting functions. 
The function invokes particular methods which depend on the class of the first argument. 
}
\section{Methods}{
\describe{
\item{object = "ANY"}{Any object for which a summary is desired, 
    dispatches to the S3 generic.}
\item{object = "Wave"}{The \code{\link{Wave}} object is beeing \code{show}ed, and an additional summary of the 
    \code{Wave}-object's (one or two) channels is given.}
\item{object = "Wspec"}{The \code{\link{Wspec}} object is beeing \code{show}ed, and as an additional output is given:
    \code{df}, \code{taper} (see \code{\link{spectrum}}), 
    and for the underlying \code{\link{Wave}} object the number of channels and its sampling rate.}
}}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\seealso{For the S3 generic: \code{\link[base]{summary.default}}, \code{\link{plot-methods}}, 
    \code{\link{Wave}}, \code{\link{Wspec}}}
\keyword{methods}
\keyword{print}

\eof
\name{tuneR}
\alias{tuneR}
\title{tuneR}
\description{tuneR, a collection of examples}
\section{Functions in tuneR}{
\emph{tuneR} consists of several functions to work with and to analyze Wave files.
In the following examples, some of the functions 
to read and write Wave files (\code{\link{readWave}}, \code{\link{writeWave}}),
to represent or construct Wave files (\code{\link{Wave}}),
to transform  Wave objects (\code{\link{bind}}, \code{\link{channel}}, 
\code{\link{downsample}}, \code{\link{extractWave}}, \code{\link{mono}}, \code{\link{stereo}}),
and to \code{\link{play}} Wave objects are used.
Other functions and classes are avaiable to 
calculate several periodograms of a signal (\code{\link{periodogram}}, \code{\link{Wspec}}),
to estimate the corresponding fundamental frequencies (\code{\link{FF}}, \code{\link{FFpure}}),
to derive the corresponding notes (\code{\link{noteFromFF}}), 
and to apply a \code{\link{smoother}}.
Of course, print (show), plot and summary methods are available for most classes.
Moreover, a function called \code{\link{lilyinput}} can prepare a data frame to be presented 
as sheet music by postprocessing with the music typesetting software LilyPond.
}
\author{Uwe Ligges, \email{ligges@statistik.uni-dortmund.de}}
\examples{
\dontrun{
# library(tuneR) # in a regular session, we are loading tuneR
  
# constructing a mono Wave object (2 sec.) containing sinus 
# sound with 440Hz and folled by 220Hz:
x <- seq(0, 2*pi, length = 44100)
channel <- round(32000 * c(sin(440 * x), sin(220 * x)))
Wobj <- Wave(left = channel)
show(Wobj)
plot(Wobj) # it does not make sense to plot the whole stuff
plot(extractWave(Wobj, from = 1, to = 500))
play(Wobj) # listen to the sound

# write the Wave object into a Wave file (can be played with any player):
writeWave(Wobj, "testfile.wav")
# reading it in again:
Wobj2 <- readWave("testfile.wav")
identical(Wobj2, Wobj) # it is still the same 

Wobjm <- mono(Wobj, "left") # extract the left channel
# and downsample to 11025 samples/sec.:
Wobjm11 <- downsample(Wobjm, 11025)
# extract a part of the signal interactively (click for left/right limits):
Wobjm11s <- extractWave(Wobjm11)

# calculating periodograms of sections each consisting of 1024 observations,
# overlapping by 512 observations:
WspecObject <- periodogram(Wobjm11s, normalize = TRUE, width = 1024, overlap = 512)
# Let's look at the first periodogram:
plot(WspecObject, xlim = c(0, 2000), which = 1)
# calculate the fundamental frequency:
ff <- FF(WspecObject)
print(ff)
# derive note from FF given diapason a'=440
notes <- noteFromFF(ff, 440)
# smooth the notes:
snotes <- smoother(notes)
# outcome should be 0 for diapason "a'" and -12 (12 halftones lower) for "a"
print(snotes) 
# plot melody and energy of the sound:
melodyplot(WspecObject, snotes)
}
}
\keyword{documentation}


\eof
